@@ -172,6 +172,10 @@ snapd_error_get_type (void)
         { SNAPD_ERROR_ALREADY_INSTALLED, "SNAPD_ERROR_ALREADY_INSTALLED", "already-installed" },
         { SNAPD_ERROR_NOT_INSTALLED, "SNAPD_ERROR_NOT_INSTALLED", "not-installed" },
         { SNAPD_ERROR_NO_UPDATE_AVAILABLE, "SNAPD_ERROR_NO_UPDATE_AVAILABLE", "no-update-available" },
+        { SNAPD_ERROR_PASSWORD_POLICY_ERROR, "SNAPD_ERROR_PASSWORD_POLICY_ERROR", "password-policy-error" },
+        { SNAPD_ERROR_NEEDS_DEVMODE, "SNAPD_ERROR_NEEDS_DEVMODE", "needs-devmode" },
+        { SNAPD_ERROR_NEEDS_CLASSIC, "SNAPD_ERROR_NEEDS_CLASSIC", "needs-classic" },
+        { SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM, "SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM", "needs-classic-system" },
         { 0, NULL, NULL }
       };
 
