@@ -21,10 +21,24 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "./snapd-alias.h" */
+GType snapd_alias_status_get_type (void) G_GNUC_CONST;
+#define SNAPD_TYPE_ALIAS_STATUS (snapd_alias_status_get_type())
+
+/* enumerations from "./snapd-app.h" */
+GType snapd_daemon_type_get_type (void) G_GNUC_CONST;
+#define SNAPD_TYPE_DAEMON_TYPE (snapd_daemon_type_get_type())
+
 /* enumerations from "./snapd-client.h" */
 GType snapd_find_flags_get_type (void) G_GNUC_CONST;
 #define SNAPD_TYPE_FIND_FLAGS (snapd_find_flags_get_type())
 
+GType snapd_install_flags_get_type (void) G_GNUC_CONST;
+#define SNAPD_TYPE_INSTALL_FLAGS (snapd_install_flags_get_type())
+
+GType snapd_create_user_flags_get_type (void) G_GNUC_CONST;
+#define SNAPD_TYPE_CREATE_USER_FLAGS (snapd_create_user_flags_get_type())
+
 /* enumerations from "./snapd-error.h" */
 GType snapd_error_get_type (void) G_GNUC_CONST;
 #define SNAPD_TYPE_ERROR (snapd_error_get_type())
