@@ -12,25 +12,23 @@
 
 #define __SNAPD_GLIB_INSIDE__
 
+#include <snapd-glib/snapd-alias.h>
 #include <snapd-glib/snapd-app.h>
+#include <snapd-glib/snapd-assertion.h>
 #include <snapd-glib/snapd-auth-data.h>
 #include <snapd-glib/snapd-client.h>
 #include <snapd-glib/snapd-connection.h>
 #include <snapd-glib/snapd-error.h>
 #include <snapd-glib/snapd-icon.h>
 #include <snapd-glib/snapd-login.h>
-#ifdef SNAPD_BUY_SUPPORT
-#include <snapd-glib/snapd-payment-method.h>
-#endif
 #include <snapd-glib/snapd-plug.h>
-#ifdef SNAPD_BUY_SUPPORT
 #include <snapd-glib/snapd-price.h>
-#endif
 #include <snapd-glib/snapd-screenshot.h>
 #include <snapd-glib/snapd-slot.h>
 #include <snapd-glib/snapd-snap.h>
 #include <snapd-glib/snapd-system-information.h>
 #include <snapd-glib/snapd-task.h>
+#include <snapd-glib/snapd-user-information.h>
 
 #undef __SNAPD_GLIB_INSIDE__
 
