@@ -38,6 +38,7 @@ struct _SnapdSnap
     GPtrArray *apps;
     gchar *channel;
     SnapdConfinement confinement;
+    gchar *contact;
     gchar *description;
     gchar *developer;
     gboolean devmode;
@@ -60,15 +61,16 @@ struct _SnapdSnap
     gchar *version;
 };
 
-enum 
+enum
 {
     PROP_APPS = 1,
-    PROP_CHANEL,
+    PROP_CHANNEL,
     PROP_CONFINEMENT,
+    PROP_CONTACT,
     PROP_DESCRIPTION,
     PROP_DEVELOPER,
     PROP_DEVMODE,
-    PROP_DOWNLOAD_SIZE,  
+    PROP_DOWNLOAD_SIZE,
     PROP_ICON,
     PROP_ID,
     PROP_INSTALL_DATE,
@@ -84,7 +86,7 @@ enum
     PROP_TRYMODE,
     PROP_SNAP_TYPE,
     PROP_VERSION,
-    PROP_TRACKING_CHANNEL,  
+    PROP_TRACKING_CHANNEL,
     PROP_LAST
 };
 
@@ -135,6 +137,21 @@ snapd_snap_get_confinement (SnapdSnap *snap)
     return snap->confinement;
 }
 
+/**
+ * snapd_snap_get_contact:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the means of contacting the snap developer, e.g. "mailto:developer@example.com".
+ *
+ * Returns: a contact URL.
+ */
+const gchar *
+snapd_snap_get_contact (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->contact;
+}
+
 /**
  * snapd_snap_get_description:
  * @snap: a #SnapdSnap.
@@ -229,7 +246,7 @@ snapd_snap_get_id (SnapdSnap *snap)
 /**
  * snapd_snap_get_install_date:
  * @snap: a #SnapdSnap.
- * 
+ *
  * Get the date this snap was installed or %NULL if unknown.
  *
  * Returns: (transfer none) (allow-none): a #GDateTime or %NULL.
@@ -381,7 +398,7 @@ snapd_snap_get_status (SnapdSnap *snap)
 /**
  * snapd_snap_get_summary:
  * @snap: a #SnapdSnap.
- * 
+ *
  * Get a single line summary for this snap, e.g. "Best app ever!".
  *
  * Returns: a summary string.
@@ -451,13 +468,17 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         if (g_value_get_boxed (value) != NULL)
             snap->apps = g_ptr_array_ref (g_value_get_boxed (value));
         break;
-    case PROP_CHANEL:
+    case PROP_CHANNEL:
         g_free (snap->channel);
         snap->channel = g_strdup (g_value_get_string (value));
         break;
     case PROP_CONFINEMENT:
         snap->confinement = g_value_get_enum (value);
         break;
+    case PROP_CONTACT:
+        g_free (snap->contact);
+        snap->contact = g_strdup (g_value_get_string (value));
+        break;
     case PROP_DESCRIPTION:
         g_free (snap->description);
         snap->description = g_strdup (g_value_get_string (value));
@@ -548,12 +569,15 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_APPS:
         g_value_set_boxed (value, snap->apps);
         break;
-    case PROP_CHANEL:
+    case PROP_CHANNEL:
         g_value_set_string (value, snap->channel);
         break;
     case PROP_CONFINEMENT:
         g_value_set_enum (value, snap->confinement);
         break;
+    case PROP_CONTACT:
+        g_value_set_string (value, snap->contact);
+        break;
     case PROP_DESCRIPTION:
         g_value_set_string (value, snap->description);
         break;
@@ -589,7 +613,7 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
         break;
     case PROP_PRIVATE:
         g_value_set_boolean (value, snap->private);
-        break;      
+        break;
     case PROP_REVISION:
         g_value_set_string (value, snap->revision);
         break;
@@ -625,9 +649,10 @@ snapd_snap_finalize (GObject *object)
 {
     SnapdSnap *snap = SNAPD_SNAP (object);
 
-    if (snap->apps != NULL)  
+    if (snap->apps != NULL)
         g_clear_pointer (&snap->apps, g_ptr_array_unref);
     g_clear_pointer (&snap->channel, g_free);
+    g_clear_pointer (&snap->contact, g_free);
     g_clear_pointer (&snap->description, g_free);
     g_clear_pointer (&snap->developer, g_free);
     g_clear_pointer (&snap->icon, g_free);
@@ -640,7 +665,7 @@ snapd_snap_finalize (GObject *object)
     if (snap->screenshots != NULL)
         g_clear_pointer (&snap->screenshots, g_ptr_array_unref);
     g_clear_pointer (&snap->summary, g_free);
-    g_clear_pointer (&snap->tracking_channel, g_free);  
+    g_clear_pointer (&snap->tracking_channel, g_free);
     g_clear_pointer (&snap->version, g_free);
 }
 
@@ -650,7 +675,7 @@ snapd_snap_class_init (SnapdSnapClass *klass)
     GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
     gobject_class->set_property = snapd_snap_set_property;
-    gobject_class->get_property = snapd_snap_get_property; 
+    gobject_class->get_property = snapd_snap_get_property;
     gobject_class->finalize = snapd_snap_finalize;
 
     g_object_class_install_property (gobject_class,
@@ -661,7 +686,7 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          G_TYPE_PTR_ARRAY,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
-                                     PROP_CHANEL,
+                                     PROP_CHANNEL,
                                      g_param_spec_string ("channel",
                                                           "channel",
                                                           "Channel the snap is from",
@@ -674,6 +699,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                         "Confinement requested by the snap",
                                                         SNAPD_TYPE_CONFINEMENT, SNAPD_CONFINEMENT_UNKNOWN,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_CONTACT,
+                                     g_param_spec_string ("contact",
+                                                          "contact",
+                                                          "Method of contacting developer",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_DESCRIPTION,
                                      g_param_spec_string ("description",
