@@ -36,8 +36,11 @@ const gchar *snapd_task_get_summary        (SnapdTask *task);
 
 const gchar *snapd_task_get_status         (SnapdTask *task);
 
+G_DEPRECATED_FOR (snapd_change_get_ready)
 gboolean     snapd_task_get_ready          (SnapdTask *task);
 
+const gchar *snapd_task_get_progress_label (SnapdTask *task);
+
 gint64       snapd_task_get_progress_done  (SnapdTask *task);
 
 gint64       snapd_task_get_progress_total (SnapdTask *task);
