@@ -24,6 +24,7 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(int appCount READ appCount)
     Q_PROPERTY(QString channel READ channel)
     Q_PROPERTY(QSnapdConfinement confinement READ confinement)
+    Q_PROPERTY(QString contact READ contact)
     Q_PROPERTY(QString description READ description)
     Q_PROPERTY(QString developer READ developer)
     Q_PROPERTY(bool devmode READ devmode)
@@ -76,6 +77,7 @@ public:
     Q_INVOKABLE QSnapdApp *app (int) const;
     QString channel () const;
     QSnapdConfinement confinement () const;
+    QString contact () const;
     QString description () const;
     QString developer () const;
     bool devmode () const;
