@@ -17,7 +17,10 @@ class Q_DECL_EXPORT QSnapdSystemInformation : public QSnapdWrappedObject
 {
     Q_OBJECT
 
+    Q_PROPERTY(QString binariesDirectory READ binariesDirectory)
+    Q_PROPERTY(QString kernelVersion READ kernelVersion)
     Q_PROPERTY(bool managed READ managed)
+    Q_PROPERTY(QString mountDirectory READ mountDirectory)
     Q_PROPERTY(bool onClassic READ onClassic)
     Q_PROPERTY(QString osId READ osId)
     Q_PROPERTY(QString osVersion READ osVersion)
@@ -28,7 +31,10 @@ class Q_DECL_EXPORT QSnapdSystemInformation : public QSnapdWrappedObject
 public:
     explicit QSnapdSystemInformation (void *snapd_object, QObject* parent = 0);
 
+    QString binariesDirectory () const;
+    QString kernelVersion () const;
     bool managed () const;
+    QString mountDirectory () const;
     bool onClassic () const;
     QString osId () const;
     QString osVersion () const;
