@@ -127,6 +127,7 @@ mock_snap_free (MockSnap *snap)
     g_list_free_full (snap->apps, (GDestroyNotify) mock_app_free);
     g_free (snap->channel);
     g_free (snap->confinement);
+    g_free (snap->contact);
     g_free (snap->description);
     g_free (snap->developer);
     g_free (snap->icon);
@@ -228,6 +229,7 @@ mock_snap_new (const gchar *name)
     snap = g_slice_new0 (MockSnap);
     snap->channel = g_strdup ("CHANNEL");
     snap->confinement = g_strdup ("strict");
+    snap->contact = g_strdup ("CONTACT");
     snap->description = g_strdup ("DESCRIPTION");
     snap->developer = g_strdup ("DEVELOPER");
     snap->icon = g_strdup ("ICON");
@@ -357,14 +359,15 @@ mock_snapd_add_store_snap (MockSnapd *snapd, const gchar *name)
 }
 
 static MockSnap *
-mock_snapd_find_store_snap_by_name (MockSnapd *snapd, const gchar *name, const gchar *channel)
+mock_snapd_find_store_snap_by_name (MockSnapd *snapd, const gchar *name, const gchar *channel,  const gchar *revision)
 {
     GList *link;
 
     for (link = snapd->store_snaps; link; link = link->next) {
         MockSnap *snap = link->data;
         if (strcmp (snap->name, name) == 0 &&
-            (channel == NULL || g_strcmp0 (snap->channel, channel) == 0))
+            (channel == NULL || g_strcmp0 (snap->channel, channel) == 0) &&
+            (revision == NULL || g_strcmp0 (snap->revision, revision) == 0))
             return snap;
     }
 
@@ -456,6 +459,13 @@ mock_snap_set_confinement (MockSnap *snap, const gchar *confinement)
     snap->confinement = g_strdup (confinement);
 }
 
+void
+mock_snap_set_contact (MockSnap *snap, const gchar *contact)
+{
+    g_free (snap->contact);
+    snap->contact = g_strdup (contact);
+}
+
 void
 mock_snap_set_description (MockSnap *snap, const gchar *description)
 {
@@ -909,6 +919,15 @@ handle_system_info (MockSnapd *snapd, const gchar *method)
     json_builder_add_boolean_value (builder, snapd->managed);
     json_builder_set_member_name (builder, "on-classic");
     json_builder_add_boolean_value (builder, snapd->on_classic);
+    json_builder_set_member_name (builder, "kernel-version");
+    json_builder_add_string_value (builder, "KERNEL-VERSION");
+    json_builder_set_member_name (builder, "locations");
+    json_builder_begin_object (builder);
+    json_builder_set_member_name (builder, "snap-mount-dir");
+    json_builder_add_string_value (builder, "/snap");
+    json_builder_set_member_name (builder, "snap-bin-dir");
+    json_builder_add_string_value (builder, "/snap/bin");
+    json_builder_end_object (builder);
     if (snapd->store) {
         json_builder_set_member_name (builder, "store");
         json_builder_add_string_value (builder, snapd->store);
@@ -1123,8 +1142,10 @@ make_snap_node (MockSnap *snap)
         for (link = snap->apps; link; link = link->next) {
             MockApp *app = link->data;
             json_builder_begin_object (builder);
-            json_builder_set_member_name (builder, "name");
-            json_builder_add_string_value (builder, app->name);
+            if (snap->name) {
+                json_builder_set_member_name (builder, "name");
+                json_builder_add_string_value (builder, app->name);
+            }
             if (app->aliases != NULL) {
                 GList *link2;
                 json_builder_set_member_name (builder, "aliases");
@@ -1143,12 +1164,20 @@ make_snap_node (MockSnap *snap)
         }
         json_builder_end_array (builder);
     }
-    json_builder_set_member_name (builder, "channel");
-    json_builder_add_string_value (builder, snap->channel);
+    if (snap->channel) {
+        json_builder_set_member_name (builder, "channel");
+        json_builder_add_string_value (builder, snap->channel);
+    }
     json_builder_set_member_name (builder, "confinement");
     json_builder_add_string_value (builder, snap->confinement);
-    json_builder_set_member_name (builder, "description");
-    json_builder_add_string_value (builder, snap->description);
+    if (snap->contact) {
+        json_builder_set_member_name (builder, "contact");
+        json_builder_add_string_value (builder, snap->contact);
+    }
+    if (snap->description) {
+        json_builder_set_member_name (builder, "description");
+        json_builder_add_string_value (builder, snap->description);
+    }
     json_builder_set_member_name (builder, "developer");
     json_builder_add_string_value (builder, snap->developer);
     json_builder_set_member_name (builder, "devmode");
@@ -1186,8 +1215,10 @@ make_snap_node (MockSnap *snap)
         }
         json_builder_end_object (builder);
     }
-    json_builder_set_member_name (builder, "private");
-    json_builder_add_boolean_value (builder, snap->is_private);
+    if (snap->is_private) {
+        json_builder_set_member_name (builder, "private");
+        json_builder_add_boolean_value (builder, TRUE);
+    }
     json_builder_set_member_name (builder, "resource");
     resource = g_strdup_printf ("/v2/snaps/%s", snap->name);
     json_builder_add_string_value (builder, resource);
@@ -1216,8 +1247,10 @@ make_snap_node (MockSnap *snap)
     }
     json_builder_set_member_name (builder, "status");
     json_builder_add_string_value (builder, snap->status);
-    json_builder_set_member_name (builder, "summary");
-    json_builder_add_string_value (builder, snap->summary);
+    if (snap->summary) {
+        json_builder_set_member_name (builder, "summary");
+        json_builder_add_string_value (builder, snap->summary);
+    }
     if (snap->tracking_channel) {
         json_builder_set_member_name (builder, "tracking-channel");
         json_builder_add_string_value (builder, snap->tracking_channel);
@@ -1417,7 +1450,8 @@ handle_snap (MockSnapd *snapd, const gchar *method, const gchar *name, SoupMessa
     else if (strcmp (method, "POST") == 0) {
         g_autoptr(JsonNode) request = NULL;
         JsonObject *o;
-        const gchar *action, *channel = NULL;
+        const gchar *action, *channel = NULL, *revision = NULL;
+        gboolean classic = FALSE, dangerous = FALSE, devmode = FALSE, jailmode = FALSE;
 
         request = get_json (headers, body);
         if (request == NULL) {
@@ -1429,33 +1463,60 @@ handle_snap (MockSnapd *snapd, const gchar *method, const gchar *name, SoupMessa
         action = json_object_get_string_member (o, "action");
         if (json_object_has_member (o, "channel"))
             channel = json_object_get_string_member (o, "channel");
+        if (json_object_has_member (o, "revision"))
+            revision = json_object_get_string_member (o, "revision");
+        if (json_object_has_member (o, "classic"))
+            classic = json_object_get_boolean_member (o, "classic");
+        if (json_object_has_member (o, "dangerous"))
+            dangerous = json_object_get_boolean_member (o, "dangerous");
+        if (json_object_has_member (o, "devmode"))
+            devmode = json_object_get_boolean_member (o, "devmode");
+        if (json_object_has_member (o, "jailmode"))
+            jailmode = json_object_get_boolean_member (o, "jailmode");
 
         if (strcmp (action, "install") == 0) {
-            MockSnap *snap;
+            MockSnap *snap, *installed_snap;
+            MockChange *change;
 
             snap = mock_snapd_find_snap (snapd, name);
-            if (snap == NULL) {
-                snap = mock_snapd_find_store_snap_by_name (snapd, name, channel);
-                if (snap != NULL)
-                {
-                    MockSnap *snap;
-                    MockChange *change;
-
-                    snap = mock_snapd_find_snap (snapd, name);
-                    if (snap == NULL)
-                        snap = mock_snapd_add_snap (snapd, name);
-                    g_free (snap->channel);
-                    snap->channel = g_strdup (channel);
-
-                    change = add_change (snapd, NULL);
-                    add_task (change, "install");
-                    send_async_response (snapd, 202, "Accepted", change->id);
-                }
-                else
-                    send_error_bad_request (snapd, "cannot install, snap not found", NULL);
-            }
-            else
+            if (snap != NULL) {
                 send_error_bad_request (snapd, "snap is already installed", "snap-already-installed");
+                return;
+            }
+
+            snap = mock_snapd_find_store_snap_by_name (snapd, name, channel, revision);
+            if (snap == NULL) {
+                send_error_bad_request (snapd, "cannot install, snap not found", NULL);
+                return;
+            }
+
+            if (strcmp (snap->confinement, "classic") == 0 && !classic) {
+                send_error_bad_request (snapd, "requires classic confinement", "snap-needs-classic");
+                return;
+            }
+            if (strcmp (snap->confinement, "classic") == 0 && !snapd->on_classic) {
+                send_error_bad_request (snapd, "requires classic confinement", "snap-needs-classic-system");
+                return;
+            }
+            if (strcmp (snap->confinement, "devmode") == 0 && !devmode) {
+                send_error_bad_request (snapd, "requires devmode or confinement override", "snap-needs-devmode");
+                return;
+            }
+
+            installed_snap = mock_snapd_add_snap (snapd, name);
+            g_free (installed_snap->confinement);
+            installed_snap->confinement = g_strdup (snap->confinement);
+            g_free (installed_snap->channel);
+            installed_snap->channel = g_strdup (snap->channel);
+            g_free (installed_snap->revision);
+            installed_snap->revision = g_strdup (snap->revision);
+            installed_snap->devmode = devmode;
+            installed_snap->jailmode = jailmode;
+            installed_snap->dangerous = dangerous;
+
+            change = add_change (snapd, NULL);
+            add_task (change, "install");
+            send_async_response (snapd, 202, "Accepted", change->id);
         }
         else if (strcmp (action, "refresh") == 0) {
             MockSnap *snap;
@@ -1466,7 +1527,7 @@ handle_snap (MockSnapd *snapd, const gchar *method, const gchar *name, SoupMessa
                 MockSnap *store_snap;
 
                 /* Find if we have a store snap with a newer revision */
-                store_snap = mock_snapd_find_store_snap_by_name (snapd, name, channel);
+                store_snap = mock_snapd_find_store_snap_by_name (snapd, name, channel, NULL);
                 if (store_snap != NULL && strcmp (store_snap->revision, snap->revision) > 0) {
                     MockChange *change;
 
